@@ -1,3 +1,5 @@
+# flake8: noqa
+
 from __future__ import annotations
 
 import logging
@@ -5,7 +7,7 @@ import re
 from functools import lru_cache
 from numbers import Integral, Real
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Optional, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Optional, Sequence, Type, TypeVar, Union
 
 from ipyleaflet import Marker as LeafletMarker
 from ipywidgets import HTML
@@ -86,13 +88,13 @@ class DataFrameMixin(object):
             return cls(pd.read_pickle(path, **kwargs))
         if ".parquet" in path.suffixes:
             return cls(pd.read_parquet(path, **kwargs))
-        if ".feather" in path.suffixes:
+        if ".feather" in path.suffixes:  # coverage: ignore
             return cls(pd.read_feather(path, **kwargs))
         if ".json" in path.suffixes:
             return cls(pd.read_json(path, **kwargs))
         if ".csv" in path.suffixes:
             return cls(pd.read_csv(path, **kwargs))
-        if ".h5" == path.suffixes[-1]:
+        if ".h5" == path.suffixes[-1]:  # coverage: ignore
             return cls(pd.read_hdf(path, **kwargs))
         return None
 
@@ -107,6 +109,9 @@ class DataFrameMixin(object):
     def __len__(self) -> int:
         return self.data.shape[0]  # type: ignore
 
+    def __getitem__(self, index: Any) -> Any:
+        return self.data.iloc[index]
+
     def __rich_console__(
         self, console: Console, options: ConsoleOptions
     ) -> RenderResult:
@@ -150,6 +155,108 @@ class DataFrameMixin(object):
 
     # --- Redirected to pandas.DataFrame ---
 
+    def assign(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.assign` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.assign(*args, **kwargs))
+
+    def convert_dtypes(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.convert_dtypes` method to
+        the underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.convert_dtypes(*args, **kwargs))
+
+    def drop(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.drop` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.drop(*args, **kwargs))
+
+    def drop_duplicates(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.drop_duplicates` method to
+        the underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.drop_duplicates(*args, **kwargs))
+
+    def fillna(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.fillna` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.fillna(*args, **kwargs))
+
+    def groupby(
+        self, *args: Any, **kwargs: Any
+    ) -> pd.core.groupby.generic.DataFrameGroupBy:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.groupby` method to the
+        underlying pandas DataFrame.
+        """
+        return self.data.groupby(*args, **kwargs)
+
+    def merge(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.merge` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.merge(*args, **kwargs))
+
+    def query(
+        self: T, query_str: str, *args: Any, **kwargs: Any
+    ) -> Optional[T]:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.query` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        df = self.data.query(query_str, *args, **kwargs)
+        if df.shape[0] == 0:
+            return None
+        return self.__class__(df)
+
+    def rename(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.rename` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.rename(*args, **kwargs))
+
+    def replace(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.replace` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.replace(*args, **kwargs))
+
+    def reset_index(self: T, *args: Any, **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.reset_index` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.reset_index(*args, **kwargs))
+
+    def sort_values(self: T, by: Union[str, Sequence[str]], **kwargs: Any) -> T:
+        """
+        Applies the Pandas :meth:`~pandas.DataFrame.sort_values` method to the
+        underlying pandas DataFrame and get the result back in the same
+        structure.
+        """
+        return self.__class__(self.data.sort_values(by, **kwargs))
+
     def to_pickle(
         self, filename: Union[str, Path], *args: Any, **kwargs: Any
     ) -> None:  # coverage: ignore
@@ -241,100 +348,6 @@ class DataFrameMixin(object):
         """
         self.data.to_excel(filename, *args, **kwargs)
 
-    def sort_values(self: T, by: str, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.sort_values` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.sort_values(by, **kwargs))
-
-    def query(
-        self: T, query_str: str, *args: Any, **kwargs: Any
-    ) -> Optional[T]:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.query` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        df = self.data.query(query_str, *args, **kwargs)
-        if df.shape[0] == 0:
-            return None
-        return self.__class__(df)
-
-    def drop(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.drop` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.drop(*args, **kwargs))
-
-    def rename(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.rename` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.rename(*args, **kwargs))
-
-    def fillna(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.fillna` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.fillna(*args, **kwargs))
-
-    def groupby(
-        self, *args: Any, **kwargs: Any
-    ) -> pd.core.groupby.generic.DataFrameGroupBy:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.groupby` method to the
-        underlying pandas DataFrame.
-        """
-        return self.data.groupby(*args, **kwargs)
-
-    def assign(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.assign` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.assign(*args, **kwargs))
-
-    def drop_duplicates(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.drop_duplicates` method to
-        the underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.drop_duplicates(*args, **kwargs))
-
-    def merge(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.merge` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.merge(*args, **kwargs))
-
-    def replace(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.replace` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.replace(*args, **kwargs))
-
-    def reset_index(self: T, *args: Any, **kwargs: Any) -> T:
-        """
-        Applies the Pandas :meth:`~pandas.DataFrame.reset_index` method to the
-        underlying pandas DataFrame and get the result back in the same
-        structure.
-        """
-        return self.__class__(self.data.reset_index(*args, **kwargs))
-
 
 class ShapelyMixin(object):
 
@@ -469,6 +482,8 @@ class ShapelyMixin(object):
 class GeographyMixin(DataFrameMixin):
     """Adds Euclidean coordinates to a latitude/longitude DataFrame."""
 
+    __slots__ = ()
+
     def projection(self: T, proj: str = "lcc") -> pyproj.Proj:
         return pyproj.Proj(
             proj=proj,
@@ -725,6 +740,7 @@ class GeographyMixin(DataFrameMixin):
 
 class GeoDBMixin(DataFrameMixin):
     _extent: None | tuple[float, float, float, float] = None
+    __slots__ = ()
 
     def extent(
         self: G,
@@ -756,7 +772,7 @@ class GeoDBMixin(DataFrameMixin):
         :class:`~traffic.data.basic.navaid.Navaids`.
 
         >>> from traffic.data import airways
-        >>> airways.extent(eurofirs['LFBB'])
+        >>> airways.extent(eurofirs['LFBB'])  # doctest: +SKIP
           route    id   navaid   latitude    longitude
          ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
           A25      6    GODAN    47.64       -1.96
@@ -772,7 +788,7 @@ class GeoDBMixin(DataFrameMixin):
          ... (703 more lines)
 
         >>> from traffic.data import airports
-        >>> airports.extent("Bornholm")
+        >>> airports.extent("Bornholm")  # doctest: +SKIP
          name                 country   icao      iata   latitude   longitude
         ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
          Bodilsker Airstrip   Denmark   DK-0027   nan    55.06      15.05
@@ -781,25 +797,9 @@ class GeoDBMixin(DataFrameMixin):
 
         >>> from traffic.data import navaids
         >>> navaids['ZUE']
-        Navaid(
-            'ZUE',
-            type='NDB',
-            latitude=30.9,
-            longitude=20.06833333,
-            altitude=0.0,
-            description='ZUEITINA NDB',
-            frequency=' 369.0kHz'
-        )
+        Navaid('ZUE', type='NDB', latitude=30.9, longitude=20.06833333, altitude=0.0, description='ZUEITINA NDB', frequency='369.0kHz')
         >>> navaids.extent('Switzerland')['ZUE']
-        Navaid(
-            'ZUE',
-            type='VOR',
-            latitude=47.59216667,
-            longitude=8.81766667,
-            altitude=1730.0,
-            description='ZURICH EAST VOR-DME',
-            frequency='110.05MHz'
-        )
+        Navaid('ZUE', type='VOR', latitude=47.59216667, longitude=8.81766667, altitude=1730.0, description='ZURICH EAST VOR-DME', frequency='110.05MHz')
 
         """
         from cartes.osm import Nominatim
@@ -926,7 +926,7 @@ class PointMixin(object):
         return cumul
 
 
-class FormatMixin(object):
+class FormatMixin(object):  # coverage: ignore
     def __format__(self, pattern: str) -> str:
         if pattern == "":
             return repr(self)
@@ -937,7 +937,7 @@ class FormatMixin(object):
         return pattern
 
 
-class _HBox(object):
+class _HBox(object):  # coverage: ignore
     def __init__(self, *args: Any) -> None:
         self.elts = args
 
@@ -969,7 +969,7 @@ class _HBox(object):
             return _HBox(other, *self.elts)
 
 
-class HBoxMixin(object):
+class HBoxMixin(object):  # coverage: ignore
     """Enables a | operator for placing representations next to each other."""
 
     def __or__(self, other: Any) -> _HBox:
