@@ -12,6 +12,7 @@ from typing import (
 
 import rich.repr
 from ipyleaflet import GeoData as LeafletGeoData
+from ipyleaflet import Map
 from ipyleaflet import Polyline as LeafletPolyline
 
 from shapely.geometry import GeometryCollection, LineString
@@ -114,6 +115,13 @@ class Airport(
     @lru_cache()
     def _openstreetmap(self) -> "Overpass":  # coverage: ignore
         from cartes.osm import Overpass
+        from cartes.osm.requests import session
+
+        from ..data import proxy_values
+
+        if len(proxy_values) > 0:
+            session.proxies.update(proxy_values)
+            session.trust_env = False
 
         return Overpass.request(
             area={"icao": self.icao, "as_": "airport"},
@@ -129,6 +137,12 @@ class Airport(
             style={**{"color": "#79706e", "weight": 6}, **kwargs},
         )
 
+    def map_leaflet(self, **kwargs: Any) -> Map:
+
+        m = Map(center=self.latlon, zoom=13)
+        m.add(self.leaflet(**kwargs))
+        return m
+
     @property
     def __geo_interface__(self) -> Optional[Dict[str, Any]]:
         df = self._openstreetmap().query('type_ != "node"')
