@@ -15,6 +15,7 @@ from typing import (
     Literal,
     NoReturn,
     Optional,
+    Sequence,
     Set,
     Type,
     TypeVar,
@@ -200,21 +201,65 @@ class Traffic(HBoxMixin, GeographyMixin):
             return None
         return self.__class__(df)
 
-    def __sub__(self, other: "Traffic") -> Optional["Traffic"]:
-        # set difference based on flight_id
-        if not isinstance(other, Traffic):
-            raise RuntimeError(
-                "Operator `-` is only applicable between Traffic structures."
-            )
-        list_id = other.flight_ids
-        if list_id is None or self.flight_ids is None:
-            raise RuntimeError(
-                "No flight_id is provided in the given Traffic structures."
-            )
-        df = self.data.query("flight_id not in @list_id")
-        if df.shape[0] == 0:
-            return None
-        return self.__class__(df)
+    def __sub__(
+        self, other: str | List[str] | Set[str] | Flight | "Traffic"
+    ) -> Optional["Traffic"]:
+
+        if isinstance(other, str):
+            other = [other]
+
+        if isinstance(other, list) or isinstance(other, set):
+            if "flight_id" in self.data.columns:
+                df = self.data.query(
+                    "flight_id not in @other and"
+                    "icao24 not in @other and callsign not in @other"
+                )
+            elif "callsign" in self.data.columns:
+                df = self.data.query(
+                    "icao24 not in @other and callsign not in @other"
+                )
+            else:
+                df = self.data.query("icao24 not in @other")
+            if df.shape[0] == 0:
+                return None
+            return self.__class__(df)
+
+        elif isinstance(other, Flight):
+            if (flight_id := other.flight_id) is None:
+                # If no flight_id is set, look icao24 and timestamps
+                df = self.data.query(
+                    "not (icao24 == @other.icao24 and "
+                    "timestamp <= @other.stop and timestamp >= @other.start)"
+                )
+                if df.shape[0] == 0:
+                    return None
+                return self.__class__(df)
+            else:
+                df = self.data.query(f"flight_id not in {repr(flight_id)}")
+                if df.shape[0] == 0:
+                    return None
+                return self.__class__(df)
+
+        elif isinstance(other, Traffic):
+            list_id = other.flight_ids
+            if list_id is not None and self.flight_ids is not None:
+                # Quite direct if we have flight_ids in both Traffic objects
+                df = self.data.query("flight_id not in @list_id")
+                if df.shape[0] == 0:
+                    return None
+                return self.__class__(df)
+            else:
+                # Remove flights one by one if no flight_id exists
+                # very not optimal, but what else...
+                res: Optional[Traffic] = self
+                for flight in other:
+                    if res is None:
+                        return None
+                    else:
+                        res = res - flight
+                return res
+
+        return self
 
     def __xor__(self, other: "Traffic") -> Optional["Traffic"]:
         left = self - other
@@ -310,10 +355,14 @@ class Traffic(HBoxMixin, GeographyMixin):
             query_str = f"callsign in {subset} or icao24 in {subset}"
             if "flight_id" in self.data.columns:
                 return self.query(f"flight_id in {subset} or " + query_str)
-            else:
+            elif "callsign" in self.data.columns:
                 return self.query(query_str)
+            else:
+                return self.query(f"icao24 in {subset}")
 
         query_str = f"callsign == '{index}' or icao24 == '{index}'"
+        if "callsign" not in self.data.columns:
+            query_str = f"icao24 == '{index}'"
         if "flight_id" in self.data.columns:
             df = self.data.query(f"flight_id == '{index}' or " + query_str)
         else:
@@ -331,6 +380,7 @@ class Traffic(HBoxMixin, GeographyMixin):
 
     def iterate(
         self,
+        on: Sequence[str] = ["icao24", "callsign"],
         by: Union[str, pd.DataFrame, None] = None,
         nb_flights: Optional[int] = None,
     ) -> Iterator[Flight]:
@@ -353,7 +403,15 @@ class Traffic(HBoxMixin, GeographyMixin):
           defines a subset of Flights to select.
         - as a a string, `by` defines the minimum time range without
           data for a flight.
+
+        If the callsign shouldn't be used for iteration, you may specify it
+        using the `on` keyword argument.
+
         """
+        # this is to avoid modifying the default keyword arg
+        on_list: str | List[str] = on if isinstance(on, str) else list(on)
+        if "callsign" not in self.data.columns and "callsign" in on_list:
+            on_list = "icao24"
 
         if isinstance(by, pd.DataFrame):
             for i, (_, line) in enumerate(by.iterrows()):
@@ -369,9 +427,7 @@ class Traffic(HBoxMixin, GeographyMixin):
                     yield Flight(df)
         else:
             for i, (_, df) in enumerate(
-                self.data.sort_values("timestamp").groupby(
-                    ["icao24", "callsign"]
-                )
+                self.data.sort_values("timestamp").groupby(on_list)
             ):
                 if nb_flights is None or i < nb_flights:
                     yield from Flight(df).split(
@@ -530,7 +586,7 @@ class Traffic(HBoxMixin, GeographyMixin):
         without recorded data.
 
         The flight_id is created according to a pattern passed in parameter,
-        by default based on the callsign and an incremented index.
+        by default based on the callsign (if any) and an incremented index.
         """
         ...
 
@@ -539,7 +595,10 @@ class Traffic(HBoxMixin, GeographyMixin):
         ...
 
     @lazy_evaluation()
-    def intersects(self, shape: Union["Airspace", base.BaseGeometry]) -> bool:
+    def intersects(  # type: ignore
+        self,
+        shape: Union["Airspace", base.BaseGeometry],
+    ) -> bool:
         ...
 
     @lazy_evaluation()
@@ -651,11 +710,11 @@ class Traffic(HBoxMixin, GeographyMixin):
         ...
 
     @lazy_evaluation()
-    def landing_at(self, airport: str) -> bool:
+    def landing_at(self, airport: str) -> bool:  # type: ignore
         ...
 
     @lazy_evaluation()
-    def takeoff_from(self, airport: str) -> bool:
+    def takeoff_from(self, airport: str) -> bool:  # type: ignore
         ...
 
     @lazy_evaluation()
@@ -739,6 +798,8 @@ class Traffic(HBoxMixin, GeographyMixin):
     @property_cache
     def callsigns(self) -> Set[str]:
         """Return all the different callsigns in the DataFrame"""
+        if "callsign" not in self.data.columns:
+            return set()
         sub = self.data.query("callsign == callsign")
         if sub.shape[0] == 0:
             return set()
@@ -785,7 +846,10 @@ class Traffic(HBoxMixin, GeographyMixin):
 
     @property_cache
     def basic_stats(self) -> pd.DataFrame:
-        key = ["icao24", "callsign"] if self.flight_ids is None else "flight_id"
+        default_key = ["icao24", "callsign"]
+        if "callsign" not in self.data.columns:
+            default_key = list(elt for elt in default_key if elt != "callsign")
+        key = default_key if self.flight_ids is None else "flight_id"
         return (
             self.data.groupby(key)[["timestamp"]]
             .count()
@@ -851,11 +915,11 @@ class Traffic(HBoxMixin, GeographyMixin):
         m = LeafletMap(zoom=zoom, **kwargs)
 
         if _airport is not None:
-            m.add_layer(_airport)
+            m.add(_airport)
 
         for flight in self:
             if flight.query("latitude == latitude"):
-                elt = m.add_layer(flight)
+                elt = m.add(flight)
                 elt.popup = HTML()
                 elt.popup.value = flight._info_html()
 
@@ -874,7 +938,7 @@ class Traffic(HBoxMixin, GeographyMixin):
                 else:
                     f = value(flight)
                 if f is not None:
-                    m.add_layer(f, color=color)
+                    m.add(f, color=color)
 
         return m
 
@@ -1100,6 +1164,9 @@ class Traffic(HBoxMixin, GeographyMixin):
         if "last_position" not in self.data.columns:
             return self
 
+        if "callsign" not in self.data.columns:
+            return self
+
         return self.__class__(
             self.data.groupby(["icao24", "callsign"]).filter(
                 lambda x: x.drop_duplicates("last_position").count().max()
