@@ -8,7 +8,7 @@ from requests import Session
 from .. import cache_dir, config, config_file
 
 if TYPE_CHECKING:
-    from .adsb.decode import ModeS_Decoder as ModeS_Decoder
+    from .adsb.decode import ModeS_Decoder
     from .adsb.opensky import OpenSky
     from .basic.aircraft import Aircraft
     from .basic.airports import Airports
@@ -32,7 +32,6 @@ __all__ = [
     "aircraft",
     "airports",
     "airways",
-    "carto_session",
     "navaids",
     "runways",
     "aixm_airports",
@@ -54,7 +53,6 @@ __all__ = [
 aircraft: "Aircraft"
 airports: "Airports"
 airways: "Airways"
-carto_session: Session
 navaids: "Navaids"
 runways: "Runways"
 aixm_airports: "AIXMAirportParser"
@@ -158,17 +156,6 @@ def __getattr__(name: str) -> Any:
         _cached_imports[name] = res
         return res
 
-    if name == "carto_session":
-        from cartes.osm.requests import session as carto_session
-
-        if len(proxy_values) > 0:
-            carto_session.proxies.update(proxy_values)
-            carto_session.trust_env = False
-
-        res = carto_session
-        _cached_imports[name] = res
-        return res
-
     if name == "eurofirs":
         from .eurocontrol.eurofirs import eurofirs
 
@@ -283,11 +270,12 @@ def __getattr__(name: str) -> Any:
         return res
 
     if name == "session":
+        from cartes.osm.requests import session
 
-        session = Session()
         if len(proxy_values) > 0:
             session.proxies.update(proxy_values)
             session.trust_env = False
+
         res = session
         _cached_imports[name] = res
         return res
