@@ -1,4 +1,5 @@
-import sys
+import logging
+import time
 from datetime import datetime, timedelta, timezone
 from pathlib import Path
 from typing import (
@@ -9,15 +10,11 @@ from typing import (
     Optional,
     Set,
     Tuple,
+    TypedDict,
     Union,
     cast,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import TypedDict
-else:
-    from typing_extensions import TypedDict
-
 from requests import Session
 
 import pandas as pd
@@ -35,6 +32,8 @@ if TYPE_CHECKING:
     from cartopy.mpl.geoaxes import GeoAxesSubplot
     from matplotlib.artist import Artist
 
+_log = logging.getLogger(__name__)
+
 
 class Coverage(object):
     """Plots the output of the coverage json."""
@@ -230,10 +229,20 @@ class OpenSky(Impala):
         c = self.session.get(
             f"https://opensky-network.org/api/states/{what}", auth=self.auth
         )
-        c.raise_for_status()
-        r = pd.DataFrame.from_records(
-            c.json()["states"], columns=self._json_columns
-        )
+        try:
+            c.raise_for_status()
+            json = c.json()
+            columns = self._json_columns
+            # For some reason, OpenSky may return 18 fields instead of 17
+            if len(json["states"]) > 0:
+                if len(json["states"][0]) > len(self._json_columns):
+                    columns.append("_")
+            r = pd.DataFrame.from_records(json["states"], columns=columns)
+        except Exception:
+            _log.warning("Error in received data, retrying in 10 seconds")
+            time.sleep(10)
+            return self.api_states(own, bounds)
+
         r = r.drop(["origin_country", "spi", "sensors"], axis=1)
         r = r.dropna()
 
