@@ -1,17 +1,20 @@
 from __future__ import annotations
 
+import gzip
 import hashlib
 import logging
 import re
 import string
 import time
+from contextlib import contextmanager
 from datetime import timedelta
 from io import StringIO
 from pathlib import Path
 from tempfile import gettempdir
-from typing import Any, Dict, Iterable, List, Tuple, cast
+from typing import Any, Dict, Generator, Iterable, List, TextIO, Tuple, cast
 
 import paramiko
+from cartes.osm import Nominatim
 from tqdm.rich import tqdm
 
 import pandas as pd
@@ -21,6 +24,7 @@ from shapely.geometry.base import BaseGeometry
 from ...core import Flight, Traffic
 from ...core.time import round_time, split_times, timelike, to_datetime
 from ...core.types import ProgressbarType
+from .flarm_data import FlarmData
 from .raw_data import RawData
 
 _log = logging.getLogger(__name__)
@@ -30,6 +34,23 @@ class ImpalaError(Exception):
     pass
 
 
+@contextmanager
+def open_cache_file(cachename: Path) -> Generator[TextIO, None, None]:
+    """Get a file object for the cache
+
+    This abstracts away the compression status of the cache file.
+    """
+    with cachename.open("rb") as bytes_header:
+        if bytes_header.read(3) == b"\x1f\x8b\x08":
+            _log.info("Opening as Gzip {}".format(cachename))
+            with gzip.open(cachename, "rt") as fh:
+                yield fh
+        else:
+            _log.info("Opening as plain text {}".format(cachename))
+            with cachename.open("r") as fh:
+                yield fh
+
+
 class Impala(object):
 
     _impala_columns = [
@@ -53,6 +74,31 @@ class Impala(object):
         "hour",
     ]
 
+    _flarm_columns = [
+        "sensortype",
+        "sensorlatitude",
+        "sensorlongitude",
+        "sensoraltitude",
+        "timeatserver",
+        "timeatsensor",
+        "timestamp",
+        "timeatplane",
+        "rawmessage",
+        "crc",
+        "rawsoftmessage",
+        "sensorname",
+        "ntperror",
+        "userfreqcorrection",
+        "autofreqcorrection",
+        "frequency",
+        "channel",
+        "snrdetector",
+        "snrdemodulator",
+        "typeogn",
+        "crccorrect",
+        "hour",
+    ]
+
     _raw_tables = [
         "acas_data4",
         "allcall_replies_data4",
@@ -70,6 +116,12 @@ class Impala(object):
         "{other_params}"
     )
 
+    flarm_request = (
+        "select * from flarm_raw "
+        "where hour>={before_hour} and hour<{after_hour} "
+        # "and timeatsensor>={before_time} and timeatsensor<{after_time} "
+    )
+
     _parseErrorMsg = """
     Error at parsing the cache file, moved to a temporary directory: {path}.
     Running the request again may help.
@@ -112,9 +164,8 @@ class Impala(object):
 
     @staticmethod
     def _read_cache(cachename: Path) -> None | pd.DataFrame:
-
         _log.info("Reading request in cache {}".format(cachename))
-        with cachename.open("r") as fh:
+        with open_cache_file(cachename) as fh:
             s = StringIO()
             count = 0
             for line in fh.readlines():
@@ -146,7 +197,7 @@ class Impala(object):
                 except ParserError as error:
                     for x in re.finditer(r"line (\d)+,", error.args[0]):
                         line_nb = int(x.group(1))
-                        with cachename.open("r") as fh:
+                        with open_cache_file(cachename) as fh:
                             content = fh.readlines()[line_nb - 1]
 
                     new_path = Path(gettempdir()) / cachename.name
@@ -160,7 +211,7 @@ class Impala(object):
                     return df.drop_duplicates()
 
         error_msg: None | str = None
-        with cachename.open("r") as fh:
+        with open_cache_file(cachename) as fh:
             output = fh.readlines()
             if any(elt.startswith("ERROR:") for elt in output):
                 error_msg = "".join(output[:-1])
@@ -260,7 +311,11 @@ class Impala(object):
             total += b.decode()
 
     def _impala(
-        self, request: str, columns: str, cached: bool = True
+        self,
+        request: str,
+        columns: str,
+        cached: bool = True,
+        compress: bool = False,
     ) -> None | pd.DataFrame:  # coverage: ignore
 
         digest = hashlib.md5(request.encode("utf8")).hexdigest()
@@ -293,7 +348,11 @@ class Impala(object):
             # If data is streamed directly into the cache file, it is hard to
             # detect that it is corrupted and should be removed/overwritten.
             _log.info("Opening {}".format(cachename))
-            with cachename.open("w") as fh:
+            if compress:
+                cache_file = gzip.open(cachename, "wt")
+            else:
+                cache_file = cachename.open("w")
+            with cache_file as fh:
                 if columns is not None:
                     fh.write(re.sub(", ", "\t", columns))
                     fh.write("\n")
@@ -373,6 +432,7 @@ class Impala(object):
         columns: list[str],
         date_delta: timedelta = timedelta(hours=1),  # noqa: B008
         cached: bool = True,
+        compress: bool = False,
         progressbar: bool | ProgressbarType[Any] = True,
     ) -> pd.DataFrame:
         """Splits and sends a custom request.
@@ -392,6 +452,9 @@ class Impala(object):
         :param cached: (default: True) switch to False to force a new request to
             the database regardless of the cached files; delete previous cache
             files;
+        :param compress: (default: False) compress cache files. Reduces disk
+            space occupied at the expense of slightly increased time
+            to load.
 
         """
 
@@ -429,7 +492,10 @@ class Impala(object):
             )
 
             df = self._impala(
-                request, columns="\t".join(columns), cached=cached
+                request,
+                columns="\t".join(columns),
+                cached=cached,
+                compress=compress,
             )
 
             if df is None:
@@ -453,6 +519,7 @@ class Impala(object):
         callsign: None | str | list[str] = None,
         icao24: None | str | list[str] = None,
         cached: bool = True,
+        compress: bool = False,
         limit: None | int = None,
         progressbar: bool | ProgressbarType[Any] = True,
     ) -> pd.DataFrame:
@@ -497,6 +564,9 @@ class Impala(object):
         :param cached: (default: True) switch to False to force a new request to
             the database regardless of the cached files. This option also
             deletes previous cache files;
+        :param compress: (default: False) compress cache files. Reduces disk
+            space occupied at the expense of slightly increased time
+            to load.
         :param limit: maximum number of records requested, LIMIT keyword in SQL.
 
         """
@@ -603,7 +673,9 @@ class Impala(object):
                 other_params=other_params,
             )
 
-            df = self._impala(request, columns=columns, cached=cached)
+            df = self._impala(
+                request, columns=columns, cached=cached, compress=compress
+            )
 
             if df is None:
                 continue
@@ -640,12 +712,16 @@ class Impala(object):
         callsign: None | str | Iterable[str] = None,
         icao24: None | str | Iterable[str] = None,
         serials: None | int | Iterable[int] = None,
-        bounds: None | BaseGeometry | Tuple[float, float, float, float] = None,
+        bounds: None
+        | str
+        | BaseGeometry
+        | Tuple[float, float, float, float] = None,
         departure_airport: None | str = None,
         arrival_airport: None | str = None,
         airport: None | str = None,
         count: bool = False,
         cached: bool = True,
+        compress: bool = False,
         limit: None | int = None,
         other_tables: str = "",
         other_params: str = "",
@@ -722,6 +798,9 @@ class Impala(object):
         :param cached: (default: True) switch to False to force a new request to
             the database regardless of the cached files. This option also
             deletes previous cache files;
+        :param compress: (default: False) compress cache files. Reduces disk
+            space occupied at the expense of slightly increased time
+            to load.
         :param limit: maximum number of records requested, LIMIT keyword in SQL.
 
         """
@@ -787,11 +866,15 @@ class Impala(object):
             other_params += "and callsign in ({}) ".format(callsign)
 
         if bounds is not None:
-            try:
+            if isinstance(bounds, str):
+                bounds = Nominatim.search(bounds)
+                if bounds is None:
+                    raise RuntimeError(f"'{bounds}' not found on Nominatim")
+            if hasattr(bounds, "bounds"):
                 # thinking of shapely bounds attribute (in this order)
                 # I just don't want to add the shapely dependency here
-                west, south, east, north = bounds.bounds  # type: ignore
-            except AttributeError:
+                west, south, east, north = bounds.bounds
+            else:
                 west, south, east, north = bounds
 
             other_params += "and lon>={} and lon<={} ".format(west, east)
@@ -923,11 +1006,18 @@ class Impala(object):
                 before_hour=bh.timestamp(),
                 after_hour=ah.timestamp(),
                 other_tables=other_tables,
-                other_params=other_params,
+                other_params=other_params.format(
+                    before_time=bt.timestamp(),
+                    after_time=at.timestamp(),
+                    before_hour=bh.timestamp(),
+                    after_hour=ah.timestamp(),
+                ),
                 where_clause=where_clause,
             )
 
-            df = self._impala(request, columns=parse_columns, cached=cached)
+            df = self._impala(
+                request, columns=parse_columns, cached=cached, compress=compress
+            )
 
             if df is None:
                 continue
@@ -935,10 +1025,6 @@ class Impala(object):
             df = self._format_dataframe(df)
             df = self._format_history(df, nautical_units=nautical_units)
 
-            if "last_position" in df.columns:
-                if df.query("last_position == last_position").shape[0] == 0:
-                    continue
-
             cumul.append(df)
 
         if len(cumul) == 0:
@@ -954,6 +1040,52 @@ class Impala(object):
 
         return Traffic(df)
 
+    def flarm(
+        self,
+        start: timelike,
+        stop: None | timelike = None,
+        *args: Any,  # more reasonable to be explicit about arguments
+        sensor_name: None | str | list[str] = None,
+        cached: bool = True,
+        compress: bool = False,
+        limit: None | int = None,
+        other_params: str = "",
+        progressbar: bool | ProgressbarType[Any] = True,
+    ) -> None | FlarmData:
+
+        other_params += "and rawmessage = rawmessage and crccorrect "
+        other_params += "and not typeogn "
+
+        if isinstance(sensor_name, str):
+            if sensor_name.find("%") > 0 or sensor_name.find("_") > 0:
+                other_params += "and sensorname ilike '{}' ".format(sensor_name)
+            else:
+                other_params += "and sensorname='{:<8s}' ".format(sensor_name)
+
+        elif isinstance(sensor_name, Iterable):
+            sensor_name = ", ".join(sensor_name)
+            other_params += "and sensorname in ({}) ".format(sensor_name)
+
+        if limit is not None:
+            other_params += f"limit {limit}"
+
+        pattern = self.flarm_request + other_params
+
+        data = self.request(
+            request_pattern=pattern,
+            start=start,
+            stop=stop,
+            columns=self._flarm_columns,
+            cached=cached,
+            compress=compress,
+            progressbar=progressbar,
+        )
+
+        if data is None:
+            return None
+
+        return FlarmData(data)
+
     def rawdata(
         self,
         start: timelike,
@@ -969,6 +1101,7 @@ class Impala(object):
         arrival_airport: None | str = None,
         airport: None | str = None,
         cached: bool = True,
+        compress: bool = False,
         limit: None | int = None,
         other_tables: str = "",
         other_columns: None | str | list[str] = None,
@@ -1035,6 +1168,9 @@ class Impala(object):
         :param cached: (default: True) switch to False to force a new request to
             the database regardless of the cached files. This option also
             deletes previous cache files;
+        :param compress: (default: False) compress cache files. Reduces disk
+            space occupied at the expense of slightly increased time
+            to load.
         :param limit: maximum number of records requested, LIMIT keyword in SQL.
 
         """
@@ -1314,7 +1450,9 @@ class Impala(object):
                 where_clause=where_clause,
             )
 
-            df = self._impala(request, columns=parse_columns, cached=cached)
+            df = self._impala(
+                request, columns=parse_columns, cached=cached, compress=compress
+            )
 
             if df is None:
                 continue
