@@ -33,12 +33,12 @@ class Airports(GeoDBMixin):
 
     Airports information can be accessed with attributes:
 
-    >>> airports["EHAM"].latlon
-    (52.308609, 4.763889)
+    >>> airports["EHAM"].latlon  # doctest: +NUMBER
+    (52.3086, 4.7639)
     >>> airports["EHAM"].iata
-    AMS
+    'AMS'
     >>> airports["EHAM"].name
-    Amsterdam Airport Schiphol
+    'Amsterdam Airport Schiphol'
 
     """
 
@@ -46,8 +46,8 @@ class Airports(GeoDBMixin):
     expiration_days: Optional[int]
 
     src_dict = dict(
-        fr24=("airports_fr24.pkl", "download_fr24"),
-        open=("airports_ourairports.pkl", "download_airports"),
+        fr24=("airports_fr24.parquet", "download_fr24"),
+        open=("airports_ourairports.parquet", "download_airports"),
     )
 
     columns_options = dict(
@@ -116,7 +116,7 @@ class Airports(GeoDBMixin):
             ]
         ]
 
-        self._data.to_pickle(self.cache_dir / "airports_ourairports.pkl")
+        self._data.to_parquet(self.cache_dir / "airports_ourairports.parquet")
 
     def download_fr24(self) -> None:  # coverage: ignore
         from .. import session
@@ -137,7 +137,7 @@ class Airports(GeoDBMixin):
                 }
             )
         )
-        self._data.to_pickle(self.cache_dir / "airports_fr24.pkl")
+        self._data.to_parquet(self.cache_dir / "airports_fr24.parquet")
 
     @property
     def data(self) -> pd.DataFrame:
@@ -157,7 +157,7 @@ class Airports(GeoDBMixin):
             except requests.ConnectionError:
                 pass
 
-        self._data = pd.read_pickle(self.cache_dir / cache_file)
+        self._data = pd.read_parquet(self.cache_dir / cache_file)
 
         return self._data
 
@@ -167,21 +167,19 @@ class Airports(GeoDBMixin):
 
         :param name: the IATA or ICAO code of the airport
 
+        >>> from traffic.data import airports
         >>> airports["EHAM"]
-        Airport(
-            icao='EHAM',
-            iata='AMS',
-            name='Amsterdam Airport Schiphol',
-            country='Netherlands',
-            latitude=52.308601,
-            longitude=4.76389,
-            altitude=-11.0,
-        )
+        Airport(icao='EHAM', iata='AMS', name='Amsterdam Airport Schiphol', country='Netherlands', latitude=52.308, longitude=4.763, altitude=-11.0)
         """
-        x = self.data.query("iata == @name.upper() or icao == @name.upper()")
-        if x.shape[0] == 0:
-            return None
-        p = x.iloc[0]
+        if isinstance(name, int):
+            p = self.data.iloc[name]
+        else:
+            x = self.data.query(
+                "iata == @name.upper() or icao == @name.upper()"
+            )
+            if x.shape[0] == 0:
+                return None
+            p = x.iloc[0]
         return Airport(
             p.altitude,
             p.country,
@@ -195,9 +193,11 @@ class Airports(GeoDBMixin):
     def search(self, name: str) -> "Airports":
         """
         :param name: refers to the IATA or ICAO code, or part of the country
-        name, city name of full name of the airport.
+            name, city name of full name of the airport.
 
-        >>> airports.query('type == "large_airport"').search('Tokyo')
+
+        >>> from traffic.data import airports
+        >>> airports.query('type == "large_airport"').search('Tokyo')  # doctest: +SKIP
           name                                 country   icao   iata   latitude   longitude
          ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
           Narita International Airport           Japan   RJAA   NRT    35.76      140.4
