@@ -231,28 +231,19 @@ class Navaids(GeoDBMixin):
         return Navaid(**dic)
 
     def global_get(self, name: str) -> None | Navaid:
+        _log.warn("Use .get() function instead", DeprecationWarning)
+        return self.get(name)
+
+    def get(self, name: str) -> None | Navaid:
         """Search for a navaid from all alternative data sources.
 
-        >>> navaids.global_get("ZUE")
-        Navaid(
-            'ZUE',
-            type='NDB',
-            latitude=30.9,
-            longitude=20.06833333,
-            altitude=0.0,
-            description='ZUEITINA NDB',
-            frequency=' 369.0kHz'
-        )
-        >>> navaids.extent("Switzerland").global_get("ZUE")
-        Navaid(
-            'ZUE',
-            type='VOR',
-            latitude=47.59216667,
-            longitude=8.81766667,
-            altitude=1730.0,
-            description='ZURICH EAST VOR-DME',
-            frequency='110.05MHz'
-        )
+        >>> from traffic.data import navaids
+
+        >>> navaids.get("ZUE")
+        Navaid('ZUE', type='NDB', latitude=30.9, longitude=20.068, altitude=0.0, description='ZUEITINA NDB', frequency='369.0kHz')
+
+        >>> navaids.extent("Switzerland").get("ZUE")
+        Navaid('ZUE', type='VOR', latitude=47.592, longitude=8.817, altitude=1730.0, description='ZURICH EAST VOR-DME', frequency='110.05MHz')
         """
         for _key, value in reversed(
             sorted(
@@ -288,13 +279,14 @@ class Navaids(GeoDBMixin):
             The same name may match several navigational beacons in the world.
             Use the extent() method to limit the search to an area of interest.
 
-        >>> navaids.search("ZUE")
+        >>> navaids.search("ZUE")  # doctest: +SKIP
           name   type   latitude   longitude   altitude   frequency   description
          ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
           ZUE    NDB    30.9       20.07       0          369         ZUEITINA NDB
           ZUE    VOR    47.59      8.818       1730       110         ZURICH EAST VOR-DME
           ZUE    DME    47.59      8.818       1730       110         ZURICH EAST VOR-DME
-        >>> navaids.extent("Switzerland").search("ZUE")
+
+        >>> navaids.extent("Switzerland").search("ZUE")  # doctest: +SKIP
           name   type   latitude   longitude   altitude   frequency   description
          ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
           ZUE    VOR    47.59      8.818       1730       110         ZURICH EAST VOR-DME
