@@ -13,20 +13,21 @@ from typing import (
 )
 from zipfile import ZipFile
 
-import altair as alt
 import requests
-from cartopy.crs import PlateCarree
-from tqdm.autonotebook import tqdm
+from tqdm.rich import tqdm
 
+import numpy as np
 import pandas as pd
 from shapely.geometry import base, shape
 from shapely.ops import linemerge
 
 from ... import cache_expiration
 from ...core.geodesy import bearing, destination
-from ...core.mixins import HBoxMixin, PointMixin, ShapelyMixin
+from ...core.mixins import DataFrameMixin, HBoxMixin, PointMixin, ShapelyMixin
 
 if TYPE_CHECKING:
+    import altair as alt  # noqa: F401
+    from cartopy.crs import PlateCarree  # noqa: F401
     from cartopy.mpl.geoaxes import GeoAxesSubplot  # noqa: F401
 
     from ...core.structure import Airport  # noqa: F401
@@ -50,8 +51,13 @@ class Threshold(ThresholdTuple, PointMixin):
 RunwaysType = Dict[str, List[Tuple[Threshold, Threshold]]]
 
 
-class RunwayAirport(HBoxMixin, ShapelyMixin):
-    def __init__(self, runways: List[Tuple[Threshold, Threshold]]) -> None:
+class RunwayAirport(HBoxMixin, ShapelyMixin, DataFrameMixin):
+    def __init__(
+        self,
+        data: Optional[pd.DataFrame] = None,
+        runways: List[Tuple[Threshold, Threshold]] = list(),
+    ) -> None:
+        self._data: Optional[pd.DataFrame] = data
         self._runways = runways
 
     @property
@@ -94,6 +100,8 @@ class RunwayAirport(HBoxMixin, ShapelyMixin):
         **kwargs: Any,
     ) -> None:  # coverage: ignore
 
+        from cartopy.crs import PlateCarree  # noqa: F811
+
         if runways is True:
             params = {
                 "edgecolor": "#0e1111",
@@ -121,15 +129,25 @@ class RunwayAirport(HBoxMixin, ShapelyMixin):
 
             for thr in self.list:
 
+                # Placement of labels
                 lat, lon, _ = destination(
                     thr.latitude, thr.longitude, thr.bearing + 180, shift
                 )
 
-                ax.text(
-                    lon, lat, thr.name, rotation=360 - thr.bearing, **text_kw
+                # Compute the rotation of labels
+                lat2, lon2, _ = destination(lat, lon, thr.bearing + 180, 1000)
+                x1, y1 = ax.projection.transform_point(
+                    thr.longitude, thr.latitude, PlateCarree()
                 )
+                x2, y2 = ax.projection.transform_point(
+                    lon2, lat2, PlateCarree()
+                )
+                rotation = 90 + np.degrees(np.arctan2(y2 - y1, x2 - x1))
 
-    def geoencode(self, **kwargs: Any) -> alt.Chart:  # coverage: ignore
+                ax.text(lon, lat, thr.name, rotation=rotation, **text_kw)
+
+    def geoencode(self, **kwargs: Any) -> "alt.Chart":  # coverage: ignore
+        import altair as alt
 
         if kwargs.get("mode", None) == "geometry":
             params = {**{"strokeWidth": 4, "stroke": "black"}, **kwargs}
@@ -198,7 +216,7 @@ class Runways(object):
         elt = self.runways.get(airport_.icao, None)
         if elt is None:
             return None
-        return RunwayAirport(elt)
+        return RunwayAirport(runways=elt)
 
     def download_runways(self) -> None:  # coverage: ignore
         from .. import session
